@@ -9,17 +9,19 @@
  *************************************************************************/
 
 #include <assert.h>
-#include <cgraph/agxbuf.h>
-#include <cgraph/alloc.h>
-#include <cgraph/streq.h>
 #include <limits.h>
 #include <time.h>
 #include <dotgen/dot.h>
 #include <pack/pack.h>
 #include <dotgen/aspect.h>
 #include <stdbool.h>
-#include <stddef.h>
 #include <stdint.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <util/alloc.h>
+#include <util/debug.h>
+#include <util/itos.h>
+#include <util/streq.h>
 
 static void
 dot_init_subg(graph_t * g, graph_t* droot)
@@ -154,6 +156,8 @@ dot_cleanup_graph(graph_t * g)
 	dot_cleanup_graph(subg);
     }
     if (! agbindrec(g, "Agraphinfo_t", 0, true)) return;
+    free(GD_drawing(g));
+    GD_drawing(g) = NULL;
     free (GD_clust(g));
     free (GD_rankleader(g));
 
@@ -267,7 +271,7 @@ removeFill (Agraph_t * g)
 
 }
 
-#define agnodeattr(g,n,v) agattr(g,AGNODE,n,v)
+#define agnodeattr(g,n,v) agattr_text(g,AGNODE,n,v)
 
 static void
 attach_phase_attrs (Agraph_t * g, int maxphase)
@@ -275,23 +279,19 @@ attach_phase_attrs (Agraph_t * g, int maxphase)
     Agsym_t* rk = agnodeattr(g,"rank","");
     Agsym_t* order = agnodeattr(g,"order","");
     Agnode_t* n;
-    agxbuf buf = {0};
 
     for (n = agfstnode(g); n; n = agnxtnode(g,n)) {
 	if (maxphase >= 1) {
-	    agxbprint(&buf, "%d", ND_rank(n));
-	    agxset(n, rk, agxbuse(&buf));
+	    agxset(n, rk, ITOS(ND_rank(n)));
 	}
 	if (maxphase >= 2) {
-	    agxbprint(&buf, "%d", ND_order(n));
-	    agxset(n, order, agxbuse(&buf));
+	    agxset(n, order, ITOS(ND_order(n)));
 	}
     }
-    agxbfree(&buf);
 }
 
-static void dotLayout(Agraph_t * g)
-{
+/// @return 0 on success
+static int dotLayout(Agraph_t *g) {
     int maxphase = late_int(g, agfindgraphattr(g,"phase"), -1, 1);
 
     setEdgeType (g, EDGETYPE_SPLINE);
@@ -300,27 +300,37 @@ static void dotLayout(Agraph_t * g)
     dot_init_subg(g,g);
     dot_init_node_edge(g);
 
+    GV_INFO("Starting phase 1 [dot_rank]");
     dot_rank(g);
     if (maxphase == 1) {
         attach_phase_attrs (g, 1);
-        return;
+        return 0;
+    }
+    GV_INFO("Starting phase 2 [dot_mincross]");
+    const int rc = dot_mincross(g);
+    if (rc != 0) {
+        return rc;
     }
-    dot_mincross(g);
     if (maxphase == 2) {
         attach_phase_attrs (g, 2);
-        return;
+        return 0;
     }
+    GV_INFO("Starting phase 3 [dot_position]");
     dot_position(g);
     if (maxphase == 3) {
         attach_phase_attrs (g, 2);  /* positions will be attached on output */
-        return;
+        return 0;
     }
     if (GD_flags(g) & NEW_RANK)
 	removeFill (g);
     dot_sameports(g);
-    dot_splines(g);
+    const int r = dot_splines(g);
+    if (r != 0) {
+	return r;
+    }
     if (mapbool(agget(g, "compound")))
 	dot_compoundEdges(g);
+    return 0;
 }
 
 static void
@@ -338,8 +348,7 @@ initSubg (Agraph_t* sg, Agraph_t* g)
     GD_fontnames(sg) = GD_fontnames(g);
 }
 
-/* attachPos:
- * the packing library assumes all units are in inches stored in ND_pos, so we
+/* the packing library assumes all units are in inches stored in ND_pos, so we
  * have to copy the position info there.
  */
 static void
@@ -356,8 +365,7 @@ attachPos (Agraph_t* g)
     }
 }
 
-/* resetCoord:
- * Store new position info from pack library call, stored in ND_pos in inches,
+/* Store new position info from pack library call, stored in ND_pos in inches,
  * back to ND_coord in points.
  */
 static void
@@ -398,8 +406,7 @@ copyCluster (Agraph_t* scl, Agraph_t* cl)
     GD_label(scl) = NULL;
 }
 
-/* copyClusterInfo:
- * Copy cluster tree and info from components to main graph.
+/* Copy cluster tree and info from components to main graph.
  * Note that the original clusters have no Agraphinfo_t at this time.
  */
 static void copyClusterInfo(size_t ncc, Agraph_t **ccs, Agraph_t *root) {
@@ -423,11 +430,11 @@ static void copyClusterInfo(size_t ncc, Agraph_t **ccs, Agraph_t *root) {
     } 
 }
 
-/* doDot:
- * Assume g has nodes.
+/* Assume g has nodes.
+ *
+ * @return 0 on success
  */
-static void doDot (Agraph_t* g)
-{
+static int doDot(Agraph_t *g) {
     Agraph_t **ccs;
     Agraph_t *sg;
     pack_info pinfo;
@@ -439,7 +446,10 @@ static void doDot (Agraph_t* g)
 	/* No pack information; use old dot with components
          * handled during layout
          */
-	dotLayout(g);
+	const int rc = dotLayout(g);
+	if (rc != 0) {
+	    return rc;
+	}
     } else {
 	/* fill in default values */
 	if (mode == l_undef) 
@@ -454,14 +464,22 @@ static void doDot (Agraph_t* g)
 	size_t ncc;
 	ccs = cccomps(g, &ncc, 0);
 	if (ncc == 1) {
-	    dotLayout(g);
+	    const int rc = dotLayout(g);
+	    if (rc != 0) {
+		free(ccs);
+		return rc;
+	    }
 	} else if (GD_drawing(g)->ratio_kind == R_NONE) {
 	    pinfo.doSplines = true;
 
 	    for (size_t i = 0; i < ncc; i++) {
 		sg = ccs[i];
 		initSubg (sg, g);
-		dotLayout (sg);
+		const int rc = dotLayout (sg);
+		if (rc != 0) {
+		    free(ccs);
+		    return rc;
+		}
 	    }
 	    attachPos (g);
 	    packSubgraphs(ncc, ccs, g, &pinfo);
@@ -473,21 +491,29 @@ static void doDot (Agraph_t* g)
              * One possibility is to layout nodes, pack, then apply the ratio
              * adjustment. We would then have to re-adjust all positions.
              */
-	    dotLayout(g);
+	    const int rc = dotLayout(g);
+	    if (rc != 0) {
+		free(ccs);
+		return rc;
+	    }
 	}
 
 	for (size_t i = 0; i < ncc; i++) {
-	    free (GD_drawing(ccs[i]));
 	    dot_cleanup_graph(ccs[i]);
 	    agdelete(g, ccs[i]);
 	}
 	free(ccs);
     }
+    return 0;
 }
 
 void dot_layout(Agraph_t * g)
 {
-    if (agnnodes(g)) doDot (g);
+    if (agnnodes(g)) {
+	if (doDot(g) != 0) { // error?
+	    return;
+	}
+    }
     dotneato_postprocess(g);
 }
 
