@@ -1,5 +1,5 @@
 /*************************************************************************
- * Copyright (c) 2011 AT&T Intellectual Property 
+ * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -10,15 +10,16 @@
 
 #pragma once
 
+#include <util/api.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 #include <neatogen/defs.h>
 
-    extern void embed_graph(vtx_data * graph, int n, int dim, DistType ***,
-			    int);
-    extern void center_coordinate(DistType **, int, int);
+PRIVATE void embed_graph(vtx_data *graph, int n, int dim, DistType ***, int);
+PRIVATE void center_coordinate(DistType **, int, int);
 
 #ifdef __cplusplus
 }
