@@ -9,13 +9,13 @@
  *************************************************************************/
 
 #include <assert.h>
-#include <cgraph/gv_ctype.h>
 #include <inttypes.h>
 #include	<limits.h>
 #include	<sfio/sfhdr.h>
 #include	<stdbool.h>
 #include	<stddef.h>
 #include	<stdio.h>
+#include <util/gv_ctype.h>
 
 /*	The main engine for reading formatted data
 **
@@ -48,7 +48,7 @@ static const unsigned char *setclass(const unsigned char *form, bool *accept) {
 
     for (; fmt != ']'; fmt = *form++) {	/* done */
 	if (!fmt)
-	    return (form - 1);
+	    return form - 1;
 
 	/* interval */
 	if (fmt != '-' || form[0] == ']' || form[-2] > form[0])
@@ -74,7 +74,7 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 
     Argv_t argv;
 
-    int argp, argn;
+    int argn;
 
     void *value;		/* location to assign scanned value */
     const char *t_str;
@@ -146,7 +146,6 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 	t_str = NULL;
 	n_str = 0;
 	value = NULL;
-	argp = -1;
 
       loop_flags:		/* LOOP FOR FLAGS, WIDTH, BASE, TYPE */
 	switch ((fmt = *form++)) {
@@ -168,8 +167,7 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 		    if (*t_str != '*')
 			n_str = (form - 1) - t_str;
 		    else {
-			t_str = _Sffmtintf(t_str + 1, &n);
-			FP_SET(-1, argn);
+			++argn;
 
 			FMTSET(ft, form, LEFTP, 0, 0, 0, 0, 0, NULL, 0);
 			n = ft->extf(&argv, ft);
@@ -196,8 +194,8 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 		fmt = *form++;
 		goto dot_size;
 	    } else if (*form == '*') {
-		form = _Sffmtintf(form + 1, &n);
-		n = FP_SET(-1, argn);
+		form = _Sffmtintf(form + 1);
+		n = ++argn;
 
 		FMTSET(ft, form, '.', dot, 0, 0, 0, 0, NULL, 0);
 		if (ft->extf(&argv, ft) < 0)
@@ -238,8 +236,8 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 		for (n = *form; gv_isdigit(n); n = *++form)
 		    size = size * 10 + (n - '0');
 	    } else if (*form == '*') {
-		form = _Sffmtintf(form + 1, &n);
-		n = FP_SET(-1, argn);
+		form = _Sffmtintf(form + 1);
+		n = ++argn;
 
 		FMTSET(ft, form, 'I', sizeof(int), 0, 0, 0, 0, NULL, 0);
 		if (ft->extf(&argv, ft) < 0)
@@ -303,7 +301,7 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 	    }
 	}
 
-	argp = FP_SET(argp, argn);
+	++argn;
 	FMTSET(ft, form, fmt, size, flags, width, 0, base, t_str, n_str);
 	v = ft->extf(&argv, ft);
 
@@ -531,7 +529,7 @@ int sfvscanf(FILE *f, Sffmt_t *ft) {
 	    if (size < 0)
 		size = MAXWIDTH;
 	    if (value) {
-		argv.s = (char *) value;
+		argv.s = value;
 		if (fmt != 'c')
 		    size -= 1;
 	    } else
